==> libkf5incidenceeditor_16.04.2.orig.tar.xz: incidenceeditor-16.04.2/src/visualfreebusywidget.h <==
/*
  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/

#ifndef INCIDENCEEDITOR_VISUALFREEBUSYWIDGET_H
#define INCIDENCEEDITOR_VISUALFREEBUSYWIDGET_H

#include <KDateTime>

#include <QWidget>

namespace KDGantt
{
class DateTimeGrid;
class GraphicsView;
}

namespace KPIM
{
class FreeBusyItemModel;
}

class KComboBox;
class QTreeView;

namespace IncidenceEditorNG
{

class FreeBusyGanttProxyModel;
class RowController;

class VisualFreeBusyWidget : public QWidget
{
    Q_OBJECT
public:
    explicit VisualFreeBusyWidget(KPIM::FreeBusyItemModel *model, int spacing = 8, QWidget *parent = Q_NULLPTR);
    ~VisualFreeBusyWidget();

public Q_SLOTS:
    void slotUpdateIncidenceStartEnd(const KDateTime &, const KDateTime &);

Q_SIGNALS:
    void dateTimesChanged(const KDateTime &, const KDateTime &);
    void manualReload();

protected Q_SLOTS:
    void slotScaleChanged(int);
    void slotCenterOnStart();
    void slotZoomToTime();
    void slotPickDate();
    void showAttendeeStatusMenu();
    void slotIntervalColorRectangleMoved(const KDateTime &start, const KDateTime &end);

private Q_SLOTS:
    void splitterMoved();

private:
    KDGantt::GraphicsView *mGanttGraphicsView;
    QTreeView *mLeftView;
    RowController *mRowController;
    KDGantt::DateTimeGrid *mGanttGrid;
    KComboBox *mScaleCombo;
    FreeBusyGanttProxyModel *mModel;

    KDateTime mDtStart, mDtEnd;
};

}
#endif

==> libkf5incidenceeditor_18.08.3.orig.tar.xz: incidenceeditor-18.08.3/src/visualfreebusywidget.h <==
/*
  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/

#ifndef INCIDENCEEDITOR_VISUALFREEBUSYWIDGET_H
#define INCIDENCEEDITOR_VISUALFREEBUSYWIDGET_H

#include <QDateTime>
#include <QWidget>

namespace KGantt {
class DateTimeGrid;
class GraphicsView;
}

namespace CalendarSupport {
class FreeBusyItemModel;
}

class KComboBox;
class QTreeView;

namespace IncidenceEditorNG {
class FreeBusyGanttProxyModel;
class RowController;

class VisualFreeBusyWidget : public QWidget
{
    Q_OBJECT
public:
    explicit VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *model, int spacing = 8, QWidget *parent = nullptr);
    ~VisualFreeBusyWidget();

public Q_SLOTS:
    void slotUpdateIncidenceStartEnd(const QDateTime &, const QDateTime &);

Q_SIGNALS:
    void dateTimesChanged(const QDateTime &, const QDateTime &);
    void manualReload();

protected Q_SLOTS:
    void slotScaleChanged(int);
    void slotCenterOnStart();
    void slotZoomToTime();
    void slotPickDate();
    void showAttendeeStatusMenu();
    void slotIntervalColorRectangleMoved(const QDateTime &start, const QDateTime &end);

private:
    void splitterMoved();
    KGantt::GraphicsView *mGanttGraphicsView = nullptr;
    QTreeView *mLeftView = nullptr;
    RowController *mRowController = nullptr;
    KGantt::DateTimeGrid *mGanttGrid = nullptr;

    KComboBox *mScaleCombo = nullptr;
    FreeBusyGanttProxyModel *mModel = nullptr;

    QDateTime mDtStart, mDtEnd;
};
}
#endif
